

' S3C2440 Class - Version 0.1
' Written by Nicolas Gomez (Nicolas at Gomez dot CC)
'
' Copyright (c) Nicolas Gomez 2009
'
' You may use this in non-commercial projects only.
' Please contact me for other uses.
'
' Use:
'   This class helps support access to the S3C2440 registers.
'   
'
' Dependencies:
'   OpenNetCF_Mini2440 library; a library with a modified class. Specifically the modified PhysicalAddressPointer class. CFIO.dll
'
'
' Revision History
' - 0.1 - Initial Release. Defines registers for PortB, ADC, and some LCD display controller addresses.
'
'


Imports OpenNETCF_S3C2440.IO
Public Class S3C2440

    Public Const FCLK = 304800000
    Public Const HCLK = (FCLK / 3)
    Public Const PCLK = (HCLK / 2)

    Public Const GPIO_B0 = (1)
    Public Const GPIO_B1 = (1 << 1)
    Public Const GPIO_B2 = (1 << 2)
    Public Const GPIO_B3 = (1 << 3)
    Public Const GPIO_B4 = (1 << 4)
    Public Const GPIO_B5 = (1 << 5)    '100000
    Public Const GPIO_B6 = (1 << 6)
    Public Const GPIO_B7 = (1 << 7)
    Public Const GPIO_B8 = (1 << 8)

    Public Const GPIO_G0 = 1
    Public Const GPIO_G1 = (1 << 1)
    Public Const GPIO_G2 = (1 << 2)
    Public Const GPIO_G3 = (1 << 3)
    Public Const GPIO_G4 = (1 << 4)
    Public Const GPIO_G5 = (1 << 5)
    Public Const GPIO_G6 = (1 << 6)
    Public Const GPIO_G7 = (1 << 7)
    Public Const GPIO_G8 = (1 << 8)
    Public Const GPIO_G9 = (1 << 9)
    Public Const GPIO_G10 = (1 << 10)
    Public Const GPIO_G11 = (1 << 11)

    'bits within registers
    Public Const ECFLG = &H8000  '15th bit (0 based)
    Public Const ENABLE_START = 1
    Public Const READ_START = 2     '
    Public Const INVPWREN_NORMAL = 0


    Shared iADCDAT0 As New PhysicalAddressPointer(&H5800000C, &H1)
    Shared iADCDAT1 As New PhysicalAddressPointer(&H58000010, &H1)
    Shared iADCCON As New PhysicalAddressPointer(&H58000000, &H1)


    'Dim GPFDAT As New PhysicalAddressPointer(&H56000054, &H1)
    Shared iGPGDAT As New PhysicalAddressPointer(&H56000060, &H1)



    Shared iGPBCON As New PhysicalAddressPointer(&H56000010, &H1) '0x56000010 > GPCONB  register's address. Configures the pins of port B
    Shared iGPBDAT As New PhysicalAddressPointer(&H56000014, &H1) '0x56000014 > GPPORTB register's address. The data register for port B
    Shared iGPBUP As New PhysicalAddressPointer(&H56000018, &H1) 'Pull-up disable register for port B

    Shared iGPGCON As New PhysicalAddressPointer(&H56000060, &H1)
    Shared iGPGUP As New PhysicalAddressPointer(&H56000068, &H1)

    Shared iTCFG0 As New PhysicalAddressPointer(&H51000000, &H1)
    Shared iTCFG1 As New PhysicalAddressPointer(&H51000004, &H1)
    Shared iTCNTB0 As New PhysicalAddressPointer(&H5100000C, &H1)
    Shared iTCMPB0 As New PhysicalAddressPointer(&H51000010, &H1)

    Shared iTCNTB1 As New PhysicalAddressPointer(&H51000018, &H1)
    Shared iTCMPB1 As New PhysicalAddressPointer(&H5100001C, &H1)

    Shared iTCON As New PhysicalAddressPointer(&H51000008, &H1)

    Shared iLCDCON1 As New PhysicalAddressPointer(&H4D000000, &H1)
    Shared iLCDCON5 As New PhysicalAddressPointer(&H4D000010, &H1)



    Public Shared Property ADCDAT0() As UInt32
        Get
            Return iADCDAT0.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iADCDAT0.WriteInt32(value)
        End Set
    End Property
    Public Shared Property ADCDAT1() As UInt32
        Get
            Return iADCDAT1.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iADCDAT1.WriteInt32(value)
        End Set
    End Property
    Public Shared Property ADCCON() As UInt32
        Get
            Return iADCCON.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iADCCON.WriteInt32(value)
        End Set
    End Property

    Public Shared Property GPGDAT() As UInt32
        Get
            Return iGPGDAT.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPGDAT.WriteInt32(value)
        End Set
    End Property



    Public Shared Property GPBDAT() As UInt32
        Get
            Return iGPBDAT.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPBDAT.WriteInt32(value)
        End Set
    End Property

    Public Shared Property GPBCON() As UInt32
        Get
            Return iGPBCON.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPBCON.WriteInt32(value)
        End Set
    End Property
    Public Shared Property GPBUP() As UInt32
        Get
            Return iGPBUP.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPBUP.WriteInt32(value)
        End Set
    End Property

    Public Shared Property GPGCON() As UInt32
        Get
            Return iGPGCON.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPGCON.WriteInt32(value)
        End Set
    End Property

    Public Shared Property GPGUP() As UInt32
        Get
            Return iGPGUP.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iGPGUP.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCFG0() As UInt32
        Get
            Return iTCFG0.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCFG0.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCFG1() As UInt32
        Get
            Return iTCFG1.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCFG1.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCNTB0() As UInt32
        Get
            Return iTCNTB0.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCNTB0.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCMPB0() As UInt32
        Get
            Return iTCMPB0.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCMPB0.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCNTB1() As UInt32
        Get
            Return iTCNTB1.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCNTB1.WriteInt32(value)
        End Set
    End Property

    Public Shared Property TCMPB1() As UInt32
        Get
            Return iTCMPB1.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCMPB1.WriteInt32(value)
        End Set
    End Property


    Public Shared Property TCON() As UInt32
        Get
            Return iTCON.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iTCON.WriteInt32(value)
        End Set
    End Property


    Public Shared Property LCDCON1() As UInt32
        Get
            Return iLCDCON1.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iLCDCON1.WriteInt32(value)
        End Set
    End Property
    Public Shared Property LCDCON5() As UInt32
        Get
            Return iLCDCON5.ReadInt32
        End Get
        Set(ByVal value As UInt32)
            iLCDCON5.WriteInt32(value)
        End Set
    End Property
End Class

